Cluster - Kerasy Documentation
Author: Shuto
Description: Brief explanation of Cluster and introduction of modules that can be used in Kerasy

### Cluster

- 2019-12-28(土)
- ML/cluster.py

#### Purpose

Clustering algorithms are attractive for the task of class identification in spatial databases.

Notebook

Example Notebook: Kerasy.examples.cluster.ipynb

## DBSCAN

    class kerasy.ML.cluster.DBSCAN(eps=0.5, min_samples=5)

Reference

- A Density-Based Algorithm for Discovering Clusters in Large Spatial Databases with Noise

« Previous Next »